@@ -115,8 +115,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   7
-#define XINE_VERSION       "1.1.7"
+#define XINE_SUB_VERSION   8
+#define XINE_VERSION       "1.1.8"
 
 /*
  * pre-init the xine engine
@@ -1532,6 +1532,15 @@ int  xine_config_lookup_entry (xine_t *self, const char *key,
 void xine_config_update_entry (xine_t *self,
 			       const xine_cfg_entry_t *entry) XINE_PROTECTED;
 
+/*
+ * translation of old configuration entry names
+ */
+typedef struct {
+  const char *old_name, *new_name;
+} xine_config_entry_translation_t;
+
+void xine_config_set_translation_user (const xine_config_entry_translation_t *) XINE_PROTECTED;
+
 /*
  * load/save config data from/to afile (e.g. $HOME/.xine/config)
  */
