@@ -259,7 +259,7 @@ flac_decode_data (audio_decoder_t *this_gen, buf_element_t *buf)
 
         if (!this->output_open)
         {
-            this->output_open = this->stream->audio_out->open (
+            this->output_open = (this->stream->audio_out->open) (
                                             this->stream->audio_out,
                                             this->stream,
                                             this->bits_per_sample,
