@@ -64,6 +64,7 @@
 #define TAG_ICY_NOTICE2    "icy-notice2:"
 #define TAG_ICY_METAINT    "icy-metaint:"
 #define TAG_CONTENT_TYPE   "Content-Type:"
+#define TAG_LASTFM_SERVER  "Server: last.fm Streaming Server"
 
 typedef struct {
   input_plugin_t   input_plugin;
@@ -94,6 +95,9 @@ typedef struct {
   char             preview[MAX_PREVIEW_SIZE];
   off_t            preview_size;
   
+  /* Last.FM streaming server */
+  unsigned char    is_lastfm;
+
   /* ShoutCast */
   int              shoutcast_mode;
   int              shoutcast_metaint;
@@ -383,6 +387,25 @@ static off_t http_plugin_read_int (http_input_plugin_t *this,
       if (nlen < 0)
         goto error;
 
+      /* Identify SYNC string for last.fm, this is limited to last.fm
+       * streaming servers to avoid hitting on tracks metadata for other
+       * servers.
+       */
+      if ( this->is_lastfm &&
+	   memmem(&buf[read_bytes], nlen, "SYNC", 4) != NULL ) {
+	/* Tell frontend to update the UI */
+	const xine_event_t event = {
+	  .type = XINE_EVENT_UI_CHANNELS_CHANGED,
+	  .stream = this->stream,
+	  .data = NULL,
+	  .data_length = 0
+	};
+
+	lprintf("SYNC from last.fm server received\n");
+
+	xine_event_send(this->stream, &event);
+      }
+
       this->shoutcast_pos += nlen;
     }
     
@@ -643,6 +666,7 @@ static int http_plugin_open (input_plugin_t *this_gen ) {
   int                  buflen;
   int                  use_proxy;
   int                  proxyport;
+  int                  mpegurl_redirect = 0;
   
   use_proxy = this_class->proxyhost && strlen(this_class->proxyhost);
   
@@ -866,6 +890,16 @@ static int http_plugin_open (input_plugin_t *this_gen ) {
           return http_plugin_open(this_gen);
         }
 
+	{
+	  static const char mpegurl_ct_str[] = "Content-Type: audio/x-mpegurl";
+	  static const size_t mpegurl_ct_size = sizeof(mpegurl_ct_str)-1;
+	  if (!strncasecmp(this->buf, mpegurl_ct_str, mpegurl_ct_size)) {
+	    lprintf("Opening an audio/x-mpegurl file, late redirect.");
+
+	    mpegurl_redirect = 1;
+	  }
+	}
+
         /* Icecast / ShoutCast Stuff */
         if (!strncasecmp(this->buf, TAG_ICY_NAME, sizeof(TAG_ICY_NAME) - 1)) {
           _x_meta_info_set(this->stream, XINE_META_INFO_ALBUM,
@@ -907,6 +941,10 @@ static int http_plugin_open (input_plugin_t *this_gen ) {
             this->is_nsv = 1;
           }
         }
+	if ( !strncasecmp(this->buf, TAG_LASTFM_SERVER, sizeof(TAG_LASTFM_SERVER)-1) ) {
+	  lprintf("last.fm streaming server detected\n");
+	  this->is_lastfm = 1;
+	}
       }
  
       if (len == -1)
@@ -925,6 +963,30 @@ static int http_plugin_open (input_plugin_t *this_gen ) {
 
   lprintf ("end of headers\n");
 
+  if ( mpegurl_redirect ) {
+    char buf[4096] = { 0, };
+    char *newline = NULL;
+
+    http_plugin_read_int(this, buf, 4095);
+    newline = strstr(buf, "\r\n");
+
+    /* If the newline can't be found, either the 4K buffer is too small, or
+     * more likely something is fuzzy.
+     */
+    if ( newline ) {
+      char *href;
+
+      *newline = '\0';
+
+      lprintf("mpegurl pointing to %s\n", buf);
+      
+      href = _x_canonicalise_url (this->mrl, buf);
+      free(this->mrl);
+      this->mrl = href;
+      return http_plugin_open(this_gen);
+    }
+  }
+
   /*
    * fill preview buffer
    */
