@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000, 2001 Martin Norbck, Hkan Hjort
+ * Copyright (C) 2000, 2001 Martin Norbäck, Håkan Hjort
  * 
  * This file is part of libdvdnav, a DVD navigation library. It is modified
  * from a file originally part of the Ogle DVD player.
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: vmcmd.h,v 1.3 2002/08/09 22:52:14 mroi Exp $
+ * $Id: vmcmd.h,v 1.7 2003/05/11 13:44:05 jcdutton Exp $
  *
  */
 
@@ -26,10 +26,8 @@
 #define VMCMD_H_INCLUDED
 
 #include <inttypes.h>
-#include "ifo_types.h" /*  Only for vm_cmd_t  */
-#include "decoder.h"
 
-void vmPrint_mnemonic(vm_cmd_t *command);
-void vmPrint_CMD(int row, vm_cmd_t *command);
+void vm_print_mnemonic(vm_cmd_t *command);
+void vm_print_cmd(int row, vm_cmd_t *command);
 
 #endif /* VMCMD_H_INCLUDED */
