@@ -49,7 +49,12 @@
 #include "xineutils.h"
 #include "audio_out.h"
 #include "buffer.h"
-#include "dts.h"
+
+#ifdef HAVE_DTS_H
+# include <dts.h>
+#else
+# include "internal-dts.h"
+#endif
 
 #define MAX_AC5_FRAME 4096
 
@@ -153,7 +158,7 @@ static void dts_decode_frame (dts_decoder_t *this, int64_t pts, int preview_mode
     if(this->bypass_mode) {
       /* SPDIF digital output */
       if (!this->output_open) {
-        this->output_open = (this->stream->audio_out->open (this->stream->audio_out, this->stream,
+        this->output_open = ((this->stream->audio_out->open) (this->stream->audio_out, this->stream,
                                                             16, this->dts_sample_rate, 
                                                             AO_CAP_MODE_AC5));
       }
@@ -249,7 +254,7 @@ static void dts_decode_frame (dts_decoder_t *this, int64_t pts, int preview_mode
         output_mode = this->ao_flags_map[dts_output_flags & DTS_CHANNEL_MASK];
 
       if (!this->output_open) {
-        this->output_open = this->stream->audio_out->open (this->stream->audio_out, this->stream,
+        this->output_open = (this->stream->audio_out->open) (this->stream->audio_out, this->stream,
                                                            16, this->dts_sample_rate, 
                                                            output_mode);
       }
