@@ -311,6 +311,7 @@ static const ff_codec_t ff_video_lookup[] = {
   {BUF_VIDEO_KMVC,        CODEC_ID_KMVC,       "Karl Morton's Video Codec (ffmpeg)"},
   {BUF_VIDEO_FLASHSV,     CODEC_ID_FLASHSV,    "Flash Screen Video (ffmpeg)"},
   {BUF_VIDEO_CAVS,        CODEC_ID_CAVS,       "Chinese AVS (ffmpeg)"},
+  {BUF_VIDEO_THEORA_RAW,  CODEC_ID_THEORA,     "Theora (ffmpeg)"},
 };
 
 
@@ -385,7 +386,7 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
     set_stream_info(this);
   }
 
-  this->stream->video_out->open (this->stream->video_out, this->stream);
+  (this->stream->video_out->open) (this->stream->video_out, this->stream);
 
   this->skipframes = 0;
   
@@ -880,10 +881,10 @@ static void ff_handle_header_buffer (ff_video_decoder_t *this, buf_element_t *bu
       switch (codec_type) {
       case BUF_VIDEO_RV10:
       case BUF_VIDEO_RV20:
-        this->bih.biWidth  = BE_16(&this->buf[12]);
-        this->bih.biHeight = BE_16(&this->buf[14]);
+        this->bih.biWidth  = _X_BE_16(&this->buf[12]);
+        this->bih.biHeight = _X_BE_16(&this->buf[14]);
         
-        this->context->sub_id = BE_32(&this->buf[30]);
+        this->context->sub_id = _X_BE_32(&this->buf[30]);
 
         this->context->slice_offset = xine_xmalloc(sizeof(int)*SLICE_OFFSET_SIZE);
         this->slice_offset_size = SLICE_OFFSET_SIZE;
@@ -1747,7 +1748,7 @@ static uint32_t supported_video_types[] = {
   #ifdef CONFIG_CAVS_DECODER
   BUF_VIDEO_CAVS,
   #endif
-
+  BUF_VIDEO_THEORA_RAW,
   0 
 };
 
