@@ -273,7 +273,7 @@ static void mpc_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
   
   /* if the audio output is not open yet, open the audio output */
   if (!this->output_open) {
-    this->output_open = this->stream->audio_out->open(
+    this->output_open = (this->stream->audio_out->open) (
       this->stream->audio_out,
       this->stream,
       this->bits_per_sample,
