@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: qt_decoder.c,v 1.44 2006/06/11 15:09:47 valtri Exp $
+ * $Id: qt_decoder.c,v 1.45 2006/07/10 22:08:43 dgp85 Exp $
  *
  * quicktime video/audio decoder plugin, using win32 dlls
  * most of this code comes directly from MPlayer
@@ -405,7 +405,7 @@ static void qta_init_driver (qta_decoder_t *this, buf_element_t *buf) {
 
   this->frame_size = this->wave.nChannels * this->wave.wBitsPerSample / 8;
 
-  this->output_open = this->stream->audio_out->open(this->stream->audio_out, 
+  this->output_open = (this->stream->audio_out->open) (this->stream->audio_out, 
 						    this->stream,
 						    this->wave.wBitsPerSample,
 						    this->wave.nSamplesPerSec,
@@ -860,20 +860,20 @@ static void qtv_init_driver (qtv_decoder_t *this, buf_element_t *buf) {
     id=malloc (8+stdata_len) ; /* trak->stdata_len); */
     id->idSize          = 4+stdata_len;
     id->cType           = FOUR_CHAR_CODE('S','V','Q','3');
-    id->version         = BE_16 (stdata+0x08);
-    id->revisionLevel   = BE_16 (stdata+0x0C);
-    id->vendor          = BE_32 (stdata+0x10);
-    id->temporalQuality = BE_32 (stdata+0x14);
-    id->spatialQuality  = BE_32 (stdata+0x18);
-    id->width           = BE_16 (stdata+0x1C);
-    id->height          = BE_16 (stdata+0x1E);
-    id->hRes            = BE_32 (stdata+0x20);
-    id->vRes            = BE_32 (stdata+0x24);
-    id->dataSize        = BE_32 (stdata+0x28);
-    id->frameCount      = BE_16 (stdata+0x2C);
+    id->version         = _X_BE_16 (stdata+0x08);
+    id->revisionLevel   = _X_BE_16 (stdata+0x0C);
+    id->vendor          = _X_BE_32 (stdata+0x10);
+    id->temporalQuality = _X_BE_32 (stdata+0x14);
+    id->spatialQuality  = _X_BE_32 (stdata+0x18);
+    id->width           = _X_BE_16 (stdata+0x1C);
+    id->height          = _X_BE_16 (stdata+0x1E);
+    id->hRes            = _X_BE_32 (stdata+0x20);
+    id->vRes            = _X_BE_32 (stdata+0x24);
+    id->dataSize        = _X_BE_32 (stdata+0x28);
+    id->frameCount      = _X_BE_16 (stdata+0x2C);
     memcpy(&id->name,stdata+0x2D,32);
-    id->depth           = BE_16 (stdata+0x4E);
-    id->clutID          = BE_16 (stdata+0x50);
+    id->depth           = _X_BE_16 (stdata+0x4E);
+    id->clutID          = _X_BE_16 (stdata+0x50);
     if (stdata_len>0x56)	
       memcpy (((char*)&id->clutID)+2, stdata+0x52, stdata_len-0x52);
 
@@ -936,7 +936,7 @@ static void qtv_init_driver (qtv_decoder_t *this, buf_element_t *buf) {
 
   this->codec_initialized = 1;
 
-  this->stream->video_out->open (this->stream->video_out, this->stream);
+  (this->stream->video_out->open) (this->stream->video_out, this->stream);
 
   pthread_mutex_unlock(&win32_codec_mutex);
 
@@ -1139,7 +1139,7 @@ static const decoder_info_t qtv_dec_info = {
   1                        /* priority        */
 };
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_VIDEO_DECODER | PLUGIN_MUST_PRELOAD, 18, "qtv", XINE_VERSION_CODE, &qtv_dec_info, qtv_init_class },
   { PLUGIN_AUDIO_DECODER | PLUGIN_MUST_PRELOAD, 15, "qta", XINE_VERSION_CODE, &qta_dec_info, qta_init_class },
