@@ -91,7 +91,7 @@ static void nsf_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
 
     this->song_number = buf->content[4];
     /* allocate a buffer for the file */
-    this->nsf_size = BE_32(&buf->content[0]);
+    this->nsf_size = _X_BE_32(&buf->content[0]);
     this->nsf_file = xine_xmalloc(this->nsf_size);
     this->nsf_index = 0;
 
@@ -127,7 +127,7 @@ static void nsf_decode_data (audio_decoder_t *this_gen, buf_element_t *buf) {
 
   /* if the audio output is not open yet, open the audio output */
   if (!this->output_open) {
-    this->output_open = this->stream->audio_out->open(
+    this->output_open = (this->stream->audio_out->open) (
       this->stream->audio_out,
       this->stream,
       this->bits_per_sample,
