@@ -30,7 +30,7 @@
  * One more catch: Raw RGB from a Microsoft file is upside down. This is 
  * indicated by a negative height parameter.
  * 
- * $Id: rgb.c,v 1.33 2006/06/02 22:18:58 dsalt Exp $
+ * $Id: rgb.c,v 1.34 2006/07/10 22:08:43 dgp85 Exp $
  */
 
 #include <stdio.h>
@@ -121,7 +121,7 @@ static void rgb_decode_data (video_decoder_t *this_gen,
   }
   
   if (buf->decoder_flags & BUF_FLAG_STDHEADER) { /* need to initialize */
-    this->stream->video_out->open (this->stream->video_out, this->stream);
+    (this->stream->video_out->open) (this->stream->video_out, this->stream);
 
     bih = (xine_bmiheader *) buf->content;
     this->width = (bih->biWidth + 3) & ~0x03;
@@ -152,7 +152,7 @@ static void rgb_decode_data (video_decoder_t *this_gen,
 
     init_yuv_planes(&this->yuv_planes, this->width, this->height);
 
-    this->stream->video_out->open (this->stream->video_out, this->stream);
+    (this->stream->video_out->open) (this->stream->video_out, this->stream);
     this->decoder_ok = 1;
 
     /* load the stream/meta info */
@@ -203,7 +203,7 @@ static void rgb_decode_data (video_decoder_t *this_gen,
             } else if (this->bytes_per_pixel == 2) {
 
               /* ABGR1555 format, little-endian order */
-              packed_pixel = LE_16(&this->buf[buf_ptr]);
+              packed_pixel = _X_LE_16(&this->buf[buf_ptr]);
               buf_ptr += 2;
               UNPACK_BGR15(packed_pixel, r, g, b);
 
@@ -315,7 +315,7 @@ static void rgb_decode_data (video_decoder_t *this_gen,
             } else if (this->bytes_per_pixel == 2) {
 
               /* ARGB1555 format, big-endian order */
-              packed_pixel = BE_16(&this->buf[buf_ptr]);
+              packed_pixel = _X_BE_16(&this->buf[buf_ptr]);
               buf_ptr += 2;
               UNPACK_RGB15(packed_pixel, r, g, b);
 
@@ -458,7 +458,7 @@ static const decoder_info_t dec_info_video = {
   1                    /* priority        */
 };
 
-const plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_VIDEO_DECODER, 18, "rgb", XINE_VERSION_CODE, &dec_info_video, init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
