@@ -92,7 +92,7 @@ static void yuv_decode_data (video_decoder_t *this_gen,
   }
 
   if (buf->decoder_flags & BUF_FLAG_STDHEADER) { /* need to initialize */
-    this->stream->video_out->open (this->stream->video_out, this->stream);
+    (this->stream->video_out->open) (this->stream->video_out, this->stream);
 
     bih = (xine_bmiheader *) buf->content;
     this->width = (bih->biWidth + 3) & ~0x03;
