@@ -164,7 +164,7 @@ static int oscope_rewire_video(xine_post_out_t *output_gen, void *data)
   if (!data)
     return 0;
   old_port->close(old_port, XINE_ANON_STREAM);
-  new_port->open(new_port, XINE_ANON_STREAM);
+  (new_port->open) (new_port, XINE_ANON_STREAM);
   /* reconnect ourselves */
   this->vo_port = new_port;
   return 1;
@@ -194,10 +194,10 @@ static int oscope_port_open(xine_audio_port_t *port_gen, xine_stream_t *stream,
   this->sample_counter = 0;
   init_yuv_planes(&this->yuv, OSCOPE_WIDTH, OSCOPE_HEIGHT);
 
-  this->vo_port->open(this->vo_port, XINE_ANON_STREAM);
+  (this->vo_port->open) (this->vo_port, XINE_ANON_STREAM);
   this->metronom->set_master(this->metronom, stream->metronom);
 
-  return port->original_port->open(port->original_port, stream, bits, rate, mode );
+  return (port->original_port->open) (port->original_port, stream, bits, rate, mode );
 }
 
 static void oscope_port_close(xine_audio_port_t *port_gen, xine_stream_t *stream ) {
