@@ -443,17 +443,17 @@ static void xv_deinterlace_frame (xv_driver_t *this) {
       else
         recent_bitmaps[i] = NULL;
 
-    deinterlace_yuv( this->deinterlace_frame.image+frame->width*frame->height,
-		     recent_bitmaps, frame->width/2, frame->height/2, this->deinterlace_method );
+    deinterlace_yuv( this->deinterlace_frame.image + this->deinterlace_frame.xv_width * frame->height,
+		     recent_bitmaps, this->deinterlace_frame.xv_width/2, frame->height/2, this->deinterlace_method );
     for( i = 0; i < VO_NUM_RECENT_FRAMES; i++ )
       if( this->recent_frames[i] && this->recent_frames[i]->width == frame->width &&
           this->recent_frames[i]->height == frame->height )
-        recent_bitmaps[i] = this->recent_frames[i]->image + frame->width*frame->height*5/4;
+        recent_bitmaps[i] = this->recent_frames[i]->image + this->deinterlace_frame.xv_width*frame->height*5/4;
       else
         recent_bitmaps[i] = NULL;
 
-    deinterlace_yuv( this->deinterlace_frame.image+frame->width*frame->height*5/4,
-		     recent_bitmaps, frame->width/2, frame->height/2, this->deinterlace_method );
+    deinterlace_yuv( this->deinterlace_frame.image + this->deinterlace_frame.xv_width*frame->height*5/4,
+		     recent_bitmaps, this->deinterlace_frame.xv_width/2, frame->height/2, this->deinterlace_method );
 
 #else
 
@@ -472,7 +472,7 @@ static void xv_deinterlace_frame (xv_driver_t *this) {
         recent_bitmaps[i] = NULL;
 
     deinterlace_yuv( this->deinterlace_frame.image, recent_bitmaps,
-                     frame->width, frame->height, this->deinterlace_method );
+                     this->deinterlace_frame.xv_width, frame->height, this->deinterlace_method );
   }
   else {
     /*
@@ -996,28 +996,30 @@ static int xv_gui_data_exchange (vo_driver_t *this_gen,
 }
 
 static void xv_store_port_attribute(xv_driver_t *this, char *name) {
-  xv_portattribute_t  *attr;
-
   xcb_intern_atom_cookie_t atom_cookie;
   xcb_intern_atom_reply_t *atom_reply;
 
   xcb_xv_get_port_attribute_cookie_t get_attribute_cookie;
   xcb_xv_get_port_attribute_reply_t *get_attribute_reply;
   
-  attr = (xv_portattribute_t *)malloc( sizeof(xv_portattribute_t) );
-  attr->name = strdup(name);
-  
   pthread_mutex_lock(&this->main_mutex);
-  atom_cookie = xcb_intern_atom(this->connection, 0, strlen(attr->name), attr->name);
+  atom_cookie = xcb_intern_atom(this->connection, 0, strlen(name), name);
   atom_reply = xcb_intern_atom_reply(this->connection, atom_cookie, NULL);
   get_attribute_cookie = xcb_xv_get_port_attribute(this->connection, this->xv_port, atom_reply->atom);
   get_attribute_reply = xcb_xv_get_port_attribute_reply(this->connection, get_attribute_cookie, NULL);
-  attr->value = get_attribute_reply->value;
   free(atom_reply);
-  free(get_attribute_reply);
   pthread_mutex_unlock(&this->main_mutex);
   
-  xine_list_push_back (this->port_attributes, attr);
+  if (get_attribute_reply != NULL) {
+    xv_portattribute_t *attr;
+
+    attr = (xv_portattribute_t *) malloc(sizeof(xv_portattribute_t));
+    attr->name = strdup(name);
+    attr->value = get_attribute_reply->value;
+    free(get_attribute_reply);
+
+    xine_list_push_back(this->port_attributes, attr);
+  }
 }
 
 static void xv_restore_port_attributes(xv_driver_t *this) {
@@ -1409,7 +1411,7 @@ static vo_driver_t *open_plugin(video_driver_class_t *class_gen, const void *vis
 	
 	if(!strcmp(xcb_xv_attribute_info_name(attribute_it.data), "XV_HUE")) {
 	  if (!strncmp(xcb_xv_adaptor_info_name(adaptor_it.data), "NV", 2)) {
-            xprintf (this->xine, XINE_VERBOSITY_NONE, "video_out_xcbxv: ignoring broken XV_HUE settings on NVidia cards");
+            xprintf (this->xine, XINE_VERBOSITY_NONE, "video_out_xcbxv: ignoring broken XV_HUE settings on NVidia cards\n");
 	  } else {
 	    xv_check_capability (this, VO_PROP_HUE, attribute_it.data,
 			         adaptor_it.data->base_id,
