@@ -28,23 +28,23 @@
 #include "ffmpeg_bswap.h"
 
 /* These are the Aligned variants */
-#define ABE_16(x) (be2me_16(*(uint16_t*)(x)))
-#define ABE_32(x) (be2me_32(*(uint32_t*)(x)))
-#define ABE_64(x) (be2me_64(*(uint64_t*)(x)))
-#define ALE_16(x) (le2me_16(*(uint16_t*)(x)))
-#define ALE_32(x) (le2me_32(*(uint32_t*)(x)))
-#define ALE_64(x) (le2me_64(*(uint64_t*)(x)))
+#define _X_ABE_16(x) (be2me_16(*(uint16_t*)(x)))
+#define _X_ABE_32(x) (be2me_32(*(uint32_t*)(x)))
+#define _X_ABE_64(x) (be2me_64(*(uint64_t*)(x)))
+#define _X_ALE_16(x) (le2me_16(*(uint16_t*)(x)))
+#define _X_ALE_32(x) (le2me_32(*(uint32_t*)(x)))
+#define _X_ALE_64(x) (le2me_64(*(uint64_t*)(x)))
 
-#define BE_16(x) (((uint16_t)(((uint8_t*)(x))[0]) << 8) | \
+#define _X_BE_16(x) (((uint16_t)(((uint8_t*)(x))[0]) << 8) | \
                   ((uint16_t)((uint8_t*)(x))[1]))
-#define BE_24(x) (((uint32_t)(((uint8_t*)(x))[0]) << 16) | \
+#define _X_BE_24(x) (((uint32_t)(((uint8_t*)(x))[0]) << 16) | \
                   ((uint32_t)(((uint8_t*)(x))[1]) << 8) | \
                   ((uint32_t)(((uint8_t*)(x))[2])))
-#define BE_32(x) (((uint32_t)(((uint8_t*)(x))[0]) << 24) | \
+#define _X_BE_32(x) (((uint32_t)(((uint8_t*)(x))[0]) << 24) | \
                   ((uint32_t)(((uint8_t*)(x))[1]) << 16) | \
                   ((uint32_t)(((uint8_t*)(x))[2]) << 8) | \
                   ((uint32_t)((uint8_t*)(x))[3]))
-#define BE_64(x) (((uint64_t)(((uint8_t*)(x))[0]) << 56) | \
+#define _X_BE_64(x) (((uint64_t)(((uint8_t*)(x))[0]) << 56) | \
                   ((uint64_t)(((uint8_t*)(x))[1]) << 48) | \
                   ((uint64_t)(((uint8_t*)(x))[2]) << 40) | \
                   ((uint64_t)(((uint8_t*)(x))[3]) << 32) | \
@@ -53,16 +53,16 @@
                   ((uint64_t)(((uint8_t*)(x))[6]) << 8) | \
                   ((uint64_t)((uint8_t*)(x))[7]))
 
-#define LE_16(x) (((uint16_t)(((uint8_t*)(x))[1]) << 8) | \
+#define _X_LE_16(x) (((uint16_t)(((uint8_t*)(x))[1]) << 8) | \
                   ((uint16_t)((uint8_t*)(x))[0]))
-#define LE_24(x) (((uint32_t)(((uint8_t*)(x))[2]) << 16) | \
+#define _X_LE_24(x) (((uint32_t)(((uint8_t*)(x))[2]) << 16) | \
                   ((uint32_t)(((uint8_t*)(x))[1]) << 8) | \
                   ((uint32_t)(((uint8_t*)(x))[0])))
-#define LE_32(x) (((uint32_t)(((uint8_t*)(x))[3]) << 24) | \
+#define _X_LE_32(x) (((uint32_t)(((uint8_t*)(x))[3]) << 24) | \
                   ((uint32_t)(((uint8_t*)(x))[2]) << 16) | \
                   ((uint32_t)(((uint8_t*)(x))[1]) << 8) | \
                   ((uint32_t)((uint8_t*)(x))[0]))
-#define LE_64(x) (((uint64_t)(((uint8_t*)(x))[7]) << 56) | \
+#define _X_LE_64(x) (((uint64_t)(((uint8_t*)(x))[7]) << 56) | \
                   ((uint64_t)(((uint8_t*)(x))[6]) << 48) | \
                   ((uint64_t)(((uint8_t*)(x))[5]) << 40) | \
                   ((uint64_t)(((uint8_t*)(x))[4]) << 32) | \
@@ -72,19 +72,19 @@
                   ((uint64_t)((uint8_t*)(x))[0]))
 
 #ifdef WORDS_BIGENDIAN
-#define ME_16(x) BE_16(x)
-#define ME_32(x) BE_32(x)
-#define ME_64(x) BE_64(x)
-#define AME_16(x) ABE_16(x)
-#define AME_32(x) ABE_32(x)
-#define AME_64(x) ABE_64(x)
+#define _X_ME_16(x) _X_BE_16(x)
+#define _X_ME_32(x) _X_BE_32(x)
+#define _X_ME_64(x) _X_BE_64(x)
+#define _X_AME_16(x) _X_ABE_16(x)
+#define _X_AME_32(x) _X_ABE_32(x)
+#define _X_AME_64(x) _X_ABE_64(x)
 #else
-#define ME_16(x) LE_16(x)
-#define ME_32(x) LE_32(x)
-#define ME_64(x) LE_64(x)
-#define AME_16(x) ALE_16(x)
-#define AME_32(x) ALE_32(x)
-#define AME_64(x) ALE_64(x)
+#define _X_ME_16(x) _X_LE_16(x)
+#define _X_ME_32(x) _X_LE_32(x)
+#define _X_ME_64(x) _X_LE_64(x)
+#define _X_AME_16(x) _X_ALE_16(x)
+#define _X_AME_32(x) _X_ALE_32(x)
+#define _X_AME_64(x) _X_ALE_64(x)
 #endif
 
 #define BE_FOURCC( ch0, ch1, ch2, ch3 )             \
