@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: post.c,v 1.28.2.1 2005/07/17 21:50:14 miguelfreitas Exp $
+ * $Id: post.c,v 1.32 2006/01/27 07:46:15 tmattern Exp $
  */
  
 /*
@@ -59,7 +59,7 @@ static void post_video_open(xine_video_port_t *port_gen, xine_stream_t *stream)
   _x_post_rewire(port->post);
   _x_post_inc_usage(port);
   if (port->port_lock) pthread_mutex_lock(port->port_lock);
-  port->original_port->open(port->original_port, stream);
+  (port->original_port->open) (port->original_port, stream);
   if (port->port_lock) pthread_mutex_unlock(port->port_lock);
   port->stream = stream;
 }
@@ -196,7 +196,7 @@ static int post_video_rewire(xine_post_out_t *output_gen, void *data) {
   
   if (input_port->original_port->status(input_port->original_port, input_port->stream,
       &width, &height, &img_duration)) {
-    new_port->open(new_port, input_port->stream);
+    (new_port->open) (new_port, input_port->stream);
     input_port->original_port->close(input_port->original_port, input_port->stream);
   }
   input_port->original_port = new_port;
@@ -243,7 +243,7 @@ post_video_port_t *_x_post_intercept_video_port(post_plugin_t *post, xine_video_
     (*input)->xine_in.type = XINE_POST_DATA_VIDEO;
     (*input)->xine_in.data = &port->new_port;
     (*input)->post = post;
-    xine_list_append_content(post->input, *input);
+    xine_list_push_back(post->input, *input);
   }
   
   if (output) {
@@ -255,7 +255,7 @@ post_video_port_t *_x_post_intercept_video_port(post_plugin_t *post, xine_video_
     (*output)->xine_out.rewire = post_video_rewire;
     (*output)->post = post;
     (*output)->user_data = port;
-    xine_list_append_content(post->output, *output);
+    xine_list_push_back(post->output, *output);
   }
   
   return port;
@@ -362,6 +362,9 @@ vo_frame_t *_x_post_intercept_video_frame(vo_frame_t *frame, post_video_port_t *
   /* make a copy and attach the original */
   xine_fast_memcpy(new_frame, frame, sizeof(vo_frame_t));
   new_frame->next = frame;
+
+  if (new_frame->stream)
+    _x_refcounter_inc(new_frame->stream->refcounter);
   
   /* modify the frame with the intercept functions */
   new_frame->port             = &port->new_port;
@@ -399,6 +402,9 @@ vo_frame_t *_x_post_restore_video_frame(vo_frame_t *frame, post_video_port_t *po
   /* propagate any changes */
   _x_post_frame_copy_down(frame, original);
   
+  if (frame->stream)
+    _x_refcounter_dec(frame->stream->refcounter);
+
   /* put the now free slot into the free frames list */
   pthread_mutex_lock(&port->free_frames_lock);
   frame->next = port->free_frame_slots;
@@ -410,6 +416,11 @@ vo_frame_t *_x_post_restore_video_frame(vo_frame_t *frame, post_video_port_t *po
 
 void _x_post_frame_copy_down(vo_frame_t *from, vo_frame_t *to) {
   /* propagate changes downwards (from decoders to video out) */
+  if (from->stream)
+    _x_refcounter_inc(from->stream->refcounter);
+  if (to->stream)
+    _x_refcounter_dec(to->stream->refcounter);
+
   to->pts                 = from->pts;
   to->bad_frame           = from->bad_frame;
   to->duration            = from->duration;
@@ -432,8 +443,14 @@ void _x_post_frame_copy_down(vo_frame_t *from, vo_frame_t *to) {
 
 void _x_post_frame_copy_up(vo_frame_t *to, vo_frame_t *from) {
   /* propagate changes upwards (from video out to decoders) */
+  if (from->stream)
+    _x_refcounter_inc(from->stream->refcounter);
+  if (to->stream)
+    _x_refcounter_dec(to->stream->refcounter);
+
   to->vpts     = from->vpts;
   to->duration = from->duration;
+  to->stream   = from->stream;
   
   if (to->extra_info != from->extra_info)
     _x_extra_info_merge(to->extra_info, from->extra_info);
@@ -441,6 +458,11 @@ void _x_post_frame_copy_up(vo_frame_t *to, vo_frame_t *from) {
 
 void _x_post_frame_u_turn(vo_frame_t *frame, xine_stream_t *stream) {
   /* frame's travel will end here => do the housekeeping */
+  if (stream)
+    _x_refcounter_inc(stream->refcounter);
+  if (frame->stream)
+    _x_refcounter_dec(frame->stream->refcounter);
+
   frame->stream = stream;
   if (stream) {
     _x_extra_info_merge(frame->extra_info, stream->video_decoder_extra_info);
@@ -583,7 +605,7 @@ static int post_audio_open(xine_audio_port_t *port_gen, xine_stream_t *stream,
   _x_post_rewire(port->post);
   _x_post_inc_usage(port);
   if (port->port_lock) pthread_mutex_lock(port->port_lock);
-  result = port->original_port->open(port->original_port, stream, bits, rate, mode);
+  result = (port->original_port->open) (port->original_port, stream, bits, rate, mode);
   if (port->port_lock) pthread_mutex_unlock(port->port_lock);
   port->stream = stream;
   port->bits   = bits;
@@ -684,7 +706,7 @@ static int post_audio_rewire(xine_post_out_t *output_gen, void *data) {
   
   if (input_port->original_port->status(input_port->original_port, input_port->stream,
       &bits, &rate, &mode)) {
-    new_port->open(new_port, input_port->stream, bits, rate, mode);
+    (new_port->open) (new_port, input_port->stream, bits, rate, mode);
     input_port->original_port->close(input_port->original_port, input_port->stream);
   }
   input_port->original_port = new_port;
@@ -725,7 +747,7 @@ post_audio_port_t *_x_post_intercept_audio_port(post_plugin_t *post, xine_audio_
     (*input)->xine_in.type = XINE_POST_DATA_AUDIO;
     (*input)->xine_in.data = &port->new_port;
     (*input)->post = post;
-    xine_list_append_content(post->input, *input);
+    xine_list_push_back(post->input, *input);
   }
   
   if (output) {
@@ -737,7 +759,7 @@ post_audio_port_t *_x_post_intercept_audio_port(post_plugin_t *post, xine_audio_
     (*output)->xine_out.rewire = post_audio_rewire;
     (*output)->post = post;
     (*output)->user_data = port;
-    xine_list_append_content(post->output, *output);
+    xine_list_push_back(post->output, *output);
   }
   
   return port;
@@ -790,6 +812,7 @@ int _x_post_dispose(post_plugin_t *this) {
   if (!in_use) {
     xine_post_in_t  *input;
     xine_post_out_t *output;
+    xine_list_iterator_t ite;
     
     /* we can really dispose it */
     
@@ -799,8 +822,9 @@ int _x_post_dispose(post_plugin_t *this) {
     free(this->input_ids);
     free(this->output_ids);
     
-    for (input = xine_list_first_content(this->input); input;
-         input = xine_list_next_content(this->input)) {
+    for (ite = xine_list_front(this->input); ite;
+         ite = xine_list_next(this->input, ite)) {
+      input = xine_list_get_value(this->input, ite);
       switch (input->type) {
       case XINE_POST_DATA_VIDEO:
 	{
@@ -832,8 +856,9 @@ int _x_post_dispose(post_plugin_t *this) {
 	break;
       }
     }
-    for (output = xine_list_first_content(this->output); output;
-         output = xine_list_next_content(this->output)) {
+    for (ite = xine_list_front(this->output); ite;
+         ite = xine_list_next(this->output, ite)) {
+      output = xine_list_get_value(this->output, ite);
       switch (output->type) {
       case XINE_POST_DATA_VIDEO:
 	if (output->rewire == post_video_rewire)
@@ -848,8 +873,8 @@ int _x_post_dispose(post_plugin_t *this) {
       }
     }
     
-    xine_list_free(this->input);
-    xine_list_free(this->output);
+    xine_list_delete(this->input);
+    xine_list_delete(this->output);
     
     /* since the plugin loader does not know, when the plugin gets disposed,
      * we have to handle the reference counter here */
