@@ -127,17 +127,54 @@ void _x_extra_info_merge( extra_info_t *dst, extra_info_t *src ) {
   }
 }
 
+static int acquire_allowed_to_block(xine_ticket_t *this) {
+  pthread_t own_id = pthread_self();
+  unsigned entry;
+  unsigned new_size;
+
+  for(entry = 0; entry < this->holder_thread_count; ++entry) {
+    if(this->holder_threads[entry].holder == own_id) {
+      /* This thread may already hold this ticket */
+      this->holder_threads[entry].count++;
+      return (this->holder_threads[entry].count == 1);
+    }
+  }
+  /* If we get this far, this thread hasn't claimed this ticket before.
+     We need to give it a new entry in the list, then return true */
+  for(entry = 0; entry < this->holder_thread_count; ++entry) {
+    if(this->holder_threads[entry].count == 0) {
+      this->holder_threads[entry].holder = own_id;
+      this->holder_threads[entry].count = 1;
+      return 1;
+    }
+  }
+  /* List too small. Realloc to larger size */
+  new_size = this->holder_thread_count * 2;
+  lprintf("Reallocing from %d to %d entries\n", this->holder_thread_count, new_size);
+  
+  this->holder_threads = realloc(this->holder_threads, sizeof(*this->holder_threads) * new_size);
+  memset(this->holder_threads + this->holder_thread_count, 0, this->holder_thread_count);
+
+  /* Old size is equivalent to index of first newly allocated entry*/
+  this->holder_threads[this->holder_thread_count].count = 1;
+  this->holder_threads[this->holder_thread_count].holder = own_id;
+  this->holder_thread_count = new_size;
+
+  return 1;  
+}
+ 
 static int ticket_acquire_internal(xine_ticket_t *this, int irrevocable, int nonblocking) {
   int must_wait = 0;
 
   pthread_mutex_lock(&this->lock);
+  int allowed_to_block = acquire_allowed_to_block(this);
   
   if (this->ticket_revoked && !this->irrevocable_tickets)
     must_wait = !nonblocking;
   else if (this->atomic_revoke && !pthread_equal(this->atomic_revoker_thread, pthread_self()))
     must_wait = 1;
 
-  if (must_wait) {
+  if (must_wait && allowed_to_block) {
     if (nonblocking) {
       pthread_mutex_unlock(&this->lock);
       return 0;
@@ -162,9 +199,25 @@ static void ticket_acquire(xine_ticket_t *this, int irrevocable) {
   ticket_acquire_internal(this, irrevocable, 0);
 }
 
+static int release_allowed_to_block(xine_ticket_t *this) {
+  pthread_t own_id = pthread_self();
+  unsigned entry;
+  
+  for(entry = 0; entry < this->holder_thread_count; ++entry) {
+    if(this->holder_threads[entry].holder == own_id) {
+      this->holder_threads[entry].count--;
+      return this->holder_threads[entry].count == 0;
+    }
+  }
+  lprintf("BUG! Ticket 0x%p released by a thread that never took it! Allowing code to continue\n", this);
+  _x_assert(0);
+  return 1;
+}
+
 static void ticket_release_internal(xine_ticket_t *this, int irrevocable, int nonblocking) {
 
   pthread_mutex_lock(&this->lock);
+  int allowed_to_block = release_allowed_to_block(this);
   
   this->tickets_granted--;
   if (irrevocable)
@@ -172,8 +225,10 @@ static void ticket_release_internal(xine_ticket_t *this, int irrevocable, int no
   
   if (this->ticket_revoked && !this->tickets_granted)
     pthread_cond_broadcast(&this->revoked);
-  if (this->ticket_revoked && !this->irrevocable_tickets && !nonblocking)
-    pthread_cond_wait(&this->issued, &this->lock);
+  if (allowed_to_block) {
+    if (this->ticket_revoked && !this->irrevocable_tickets && !nonblocking)
+      pthread_cond_wait(&this->issued, &this->lock);
+  }
   
   pthread_mutex_unlock(&this->lock);
 }
@@ -262,6 +317,8 @@ static xine_ticket_t *ticket_init(void) {
   port_ticket->issue                = ticket_issue;
   port_ticket->revoke               = ticket_revoke;
   port_ticket->dispose              = ticket_dispose;
+  port_ticket->holder_thread_count = XINE_MAX_TICKET_HOLDER_THREADS;
+  port_ticket->holder_threads = calloc(XINE_MAX_TICKET_HOLDER_THREADS,sizeof(*port_ticket->holder_threads));
   
   pthread_mutex_init(&port_ticket->lock, NULL);
   pthread_mutex_init(&port_ticket->revoke_lock, NULL);
@@ -462,7 +519,7 @@ static int stream_rewire_audio(xine_post_out_t *output, void *data)
   
   if (stream->audio_out->status(stream->audio_out, stream, &bits, &rate, &mode)) {
     /* register our stream at the new output port */
-    new_port->open(new_port, stream, bits, rate, mode);
+    (new_port->open) (new_port, stream, bits, rate, mode);
     stream->audio_out->close(stream->audio_out, stream);
   }
   stream->audio_out = new_port;
@@ -486,7 +543,7 @@ static int stream_rewire_video(xine_post_out_t *output, void *data)
   
   if (stream->video_out->status(stream->video_out, stream, &width, &height, &img_duration)) {
     /* register our stream at the new output port */
-    new_port->open(new_port, stream);
+    (new_port->open) (new_port, stream);
     stream->video_out->close(stream->video_out, stream);
   }
   stream->video_out = new_port;
@@ -676,7 +733,7 @@ xine_stream_t *xine_stream_new (xine_t *this,
   return stream;
 }
 
-static void mrl_unescape(char *mrl) {
+void _x_mrl_unescape(char *mrl) {
   int i, len = strlen(mrl);
 
   for (i = 0; i < len; i++) {
@@ -773,7 +830,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
       _x_meta_info_set_utf8(stream, XINE_META_INFO_INPUT_PLUGIN, 
 			    (stream->input_plugin->input_class->get_identifier (stream->input_plugin->input_class)));
 
-      res = stream->input_plugin->open(stream->input_plugin);
+      res = (stream->input_plugin->open) (stream->input_plugin);
       switch(res) {
       case 1: /* Open successfull */
 	free(input_source);
@@ -824,7 +881,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	    memcpy(demux_name, tmp, strlen(tmp));
 	    demux_name[strlen(tmp)] = '\0';
 	  }
-	  mrl_unescape(demux_name);
+	  _x_mrl_unescape(demux_name);
 	  if (!(stream->demux_plugin = _x_find_demux_plugin_by_name(stream, demux_name, stream->input_plugin))) {
 	    xine_log(stream->xine, XINE_LOG_MSG, _("xine: specified demuxer %s failed to start\n"), demux_name);
 	    stream->err = XINE_ERROR_NO_DEMUX_PLUGIN;
@@ -898,7 +955,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	    memcpy(demux_name, tmp, strlen(tmp));
 	    demux_name[strlen(tmp)] = '\0';
 	  }
-	  mrl_unescape(demux_name);
+	  _x_mrl_unescape(demux_name);
 	  if (!(stream->demux_plugin = _x_find_demux_plugin_last_probe(stream, demux_name, stream->input_plugin))) {
 	    xine_log(stream->xine, XINE_LOG_MSG, _("xine: last_probed demuxer %s failed to start\n"), demux_name);
 	    stream->err = XINE_ERROR_NO_DEMUX_PLUGIN;
@@ -985,7 +1042,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	    memcpy(volume, tmp, strlen(tmp));
 	    volume[strlen(tmp)] = '\0';
 	  }
-	  mrl_unescape(volume);
+	  _x_mrl_unescape(volume);
 	  xine_set_param(stream, XINE_PARAM_AUDIO_VOLUME, atoi(volume));
 	  free(volume);
 	} else {
@@ -1010,7 +1067,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	    memcpy(compression, tmp, strlen(tmp));
 	    compression[strlen(tmp)] = '\0';
 	  }
-	  mrl_unescape(compression);
+	  _x_mrl_unescape(compression);
 	  xine_set_param(stream, XINE_PARAM_AUDIO_COMPR_LEVEL, atoi(compression));
 	  free(compression);
 	} else {
@@ -1035,7 +1092,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	    memcpy(subtitle_mrl, tmp, strlen(tmp));
 	    subtitle_mrl[strlen(tmp)] = '\0';
 	  }
-	  mrl_unescape(subtitle_mrl);
+	  _x_mrl_unescape(subtitle_mrl);
 	  stream->slave = xine_stream_new (stream->xine, NULL, stream->video_out );
 	  stream->slave_affection = XINE_MASTER_SLAVE_PLAY | XINE_MASTER_SLAVE_STOP;
 	  if( xine_open( stream->slave, subtitle_mrl ) ) {
@@ -1070,7 +1127,7 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	  memcpy(config_entry, tmp, strlen(tmp));
 	  config_entry[strlen(tmp)] = '\0';
 	}
-	mrl_unescape(config_entry);
+	_x_mrl_unescape(config_entry);
 	retval = _x_config_change_opt(stream->xine->config, config_entry);
 	if (retval <= 0) {
 	  if (retval == 0) {
